// Miscellaneous utilities implementation
#include "pch.h"

#include "util.h"

#undef max

namespace nf::util {
    double getRand() {
        static std::random_device dev;
        return static_cast<double>(dev()) / dev.max();
    }

    double getRandRange(double minimum, double maximum) {
        return getRand() * (maximum - minimum) + minimum;
    }

    ScopedTimer::ScopedTimer(const char* funcName)
        : m_funcName(funcName)
        , m_startTime(std::chrono::high_resolution_clock::now())
    {}

    ScopedTimer::~ScopedTimer() {
        auto duration = std::chrono::duration_cast<std::chrono::microseconds>(std::chrono::high_resolution_clock::now() - m_startTime);
        ::nf::util::log(std::format("Scope in {} took {:.3f} ms", m_funcName, duration.count() * 1e-3), ::nf::util::LogType::Timing);
    }
}
